==> apache-streampipes-0.91.0-source-release.zip: apache-streampipes-0.91.0/streampipes-pipeline-management/src/test/java/org/apache/streampipes/manager/matching/v2/TestFormatMatch.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.manager.matching.v2;

import org.apache.streampipes.model.client.matching.MatchingResultMessage;
import org.apache.streampipes.model.grounding.TransportFormat;

import org.junit.Test;

import java.util.ArrayList;
import java.util.List;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

public class TestFormatMatch {

  @Test
  public void testPositiveFormatMatch() {

    TransportFormat offeredJson = TestUtils.jsonFormat();
    TransportFormat requiredJson = TestUtils.jsonFormat();

    List<MatchingResultMessage> errorLog = new ArrayList<>();

    boolean matches = new FormatMatch().match(offeredJson, requiredJson, errorLog);
    assertTrue(matches);
  }

  @Test
  public void testNegativeFormatMatch() {

    TransportFormat offeredJson = TestUtils.jsonFormat();
    TransportFormat requiredThrift = TestUtils.thriftFormat();

    List<MatchingResultMessage> errorLog = new ArrayList<>();

    boolean matches = new FormatMatch().match(offeredJson, requiredThrift, errorLog);
    assertFalse(matches);
  }
}

==> apache-streampipes-0.95.1-source-release.zip: apache-streampipes-0.95.1/streampipes-pipeline-management/src/test/java/org/apache/streampipes/manager/matching/v2/TestFormatMatch.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.manager.matching.v2;

import org.apache.streampipes.model.client.matching.MatchingResultMessage;
import org.apache.streampipes.model.grounding.TransportFormat;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import java.util.ArrayList;
import java.util.List;

public class TestFormatMatch {

  @Test
  public void testPositiveFormatMatch() {

    TransportFormat offeredJson = TestUtils.jsonFormat();
    TransportFormat requiredJson = TestUtils.jsonFormat();

    List<MatchingResultMessage> errorLog = new ArrayList<>();

    boolean matches = new FormatMatch().match(offeredJson, requiredJson, errorLog);
    Assertions.assertTrue(matches);
  }

  @Test
  public void testNegativeFormatMatch() {

    TransportFormat offeredJson = TestUtils.jsonFormat();
    TransportFormat requiredThrift = TestUtils.thriftFormat();

    List<MatchingResultMessage> errorLog = new ArrayList<>();

    boolean matches = new FormatMatch().match(offeredJson, requiredThrift, errorLog);
    Assertions.assertFalse(matches);
  }
}
